<?php
/**
 * WebP Helper Module
 * 
 * Bu dosya, Auto WebP Converter eklentisinin bir alt modülü olarak çalışır.
 * Resimleri WebP formatına dönüştürme ve görüntüleme işlevlerini sağlar.
 */

// Doğrudan erişimi engelle
if (!defined('ABSPATH')) {
    exit;
}

// WebP Helper sınıfı
class AR_WebP_Helper {
    
    // Sınıf örneği
    private static $instance;
    
    // Eklenti ayarları
    private $settings;
    
    /**
     * Sınıf örneğini döndürür
     */
    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    
    /**
     * Yapılandırıcı
     */
    private function __construct() {
        $this->load_settings();
     	add_filter('wp_handle_upload', array($this, 'convert_to_webp'));
		add_filter('the_content', array($this, 'replace_images_with_webp'));
        add_filter('post_thumbnail_html', array($this, 'replace_images_with_webp'));
    }
    
    /**
     * Eklenti ayarlarını yükle
     */
    private function load_settings() {
        $this->settings = get_option('awc_settings', array());
    }
    
    /**
     * Ayar değerini al
     */
    public function get_setting($key, $default = '') {
        return isset($this->settings[$key]) ? $this->settings[$key] : $default;
    }
    
    /**
     * Ayarları güncelle
     */
    public function update_settings($new_settings) {
        $this->settings = array_merge($this->settings, $new_settings);
        update_option('awc_settings', $this->settings);
    }
     
    /**
     * Resmi WebP formatına dönüştür
     */
    public function convert_to_webp($file) {
        // Dosya bilgilerini al
        $file_path = $file['file'];
        $file_type = $file['type'];
        
        // Dosya uzantısını kontrol et
        $path_parts = pathinfo($file_path);
        $extension = strtolower($path_parts['extension']);
        
        // Dönüştürülecek uzantıları al
        $allowed_extensions = $this->get_setting('image_formats', array('jpg', 'jpeg', 'png', 'gif'));
        
        // Uzantı dönüştürme listesinde değilse işlem yapma
        if (!in_array($extension, $allowed_extensions)) {
            return $file;
        }
        
        // WebP dosya yolunu oluştur
        $webp_path = $path_parts['dirname'] . '/' . $path_parts['filename'] . '.webp';
        
        // Kalite ayarını al
        $quality = $this->get_setting('webp_quality', 80);
        
        // Orijinal resim boyutlarını ayarla
        $original_width = $this->get_setting('original_image_width', 0);
        $original_height = $this->get_setting('original_image_height', 0);
        
        // WebP resim boyutlarını ayarla
        $webp_width = $this->get_setting('webp_image_width', 0);
        $webp_height = $this->get_setting('webp_image_height', 0);
        
        // GD kütüphanesi ile WebP dönüştürme
        if (function_exists('imagewebp')) {
            // Kaynak resmi yükle
            $image = null;
            
            switch ($extension) {
                case 'jpg':
                case 'jpeg':
                    $image = imagecreatefromjpeg($file_path);
                    break;
                case 'png':
                    $image = imagecreatefrompng($file_path);
                    // PNG şeffaflığını koru
                    imagepalettetotruecolor($image);
                    imagealphablending($image, true);
                    imagesavealpha($image, true);
                    break;
                case 'gif':
                    $image = imagecreatefromgif($file_path);
                    break;
            }
            
            // Resim yüklenemediyse işlem yapma
            if (!$image) {
                return $file;
            }
            
            // Orijinal boyutları al
            $orig_width = imagesx($image);
            $orig_height = imagesy($image);
            
            // Orijinal resmi yeniden boyutlandır
            if ($original_width > 0 && $original_height > 0) {
                $new_image = imagecreatetruecolor($original_width, $original_height);
                
                // PNG şeffaflığını koru
                if ($extension == 'png') {
                    imagealphablending($new_image, false);
                    imagesavealpha($new_image, true);
                    $transparent = imagecolorallocatealpha($new_image, 255, 255, 255, 127);
                    imagefilledrectangle($new_image, 0, 0, $original_width, $original_height, $transparent);
                }
                
                // Yeniden boyutlandır
                imagecopyresampled($new_image, $image, 0, 0, 0, 0, $original_width, $original_height, $orig_width, $orig_height);
                
                // Eski resmi serbest bırak
                imagedestroy($image);
                $image = $new_image;
                
                // Orijinal resmi yeniden kaydet
                switch ($extension) {
                    case 'jpg':
                    case 'jpeg':
                        imagejpeg($image, $file_path, $this->get_setting('upload_quality', 90));
                        break;
                    case 'png':
                        imagepng($image, $file_path, 9);
                        break;
                    case 'gif':
                        imagegif($image, $file_path);
                        break;
                }
                
                // Dosya bilgilerini güncelle
                $file['width'] = $original_width;
                $file['height'] = $original_height;
            }
            
            // WebP için yeniden boyutlandırma
            if ($webp_width > 0 && $webp_height > 0) {
                $webp_image = imagecreatetruecolor($webp_width, $webp_height);
                
                // PNG şeffaflığını koru
                if ($extension == 'png') {
                    imagealphablending($webp_image, false);
                    imagesavealpha($webp_image, true);
                    $transparent = imagecolorallocatealpha($webp_image, 255, 255, 255, 127);
                    imagefilledrectangle($webp_image, 0, 0, $webp_width, $webp_height, $transparent);
                }
                
                // Yeniden boyutlandır
                imagecopyresampled($webp_image, $image, 0, 0, 0, 0, $webp_width, $webp_height, imagesx($image), imagesy($image));
                
                // Eski resmi serbest bırak
                imagedestroy($image);
                $image = $webp_image;
            }
            
            // WebP olarak kaydet
            imagewebp($image, $webp_path, $quality);
            
            // Belleği temizle
            imagedestroy($image);
            
            // Otomatik dönüştürme aktifse orijinal dosyayı WebP ile değiştir
            if ($this->get_setting('skip_original_upload', 'no') === 'yes') {
                $file['file'] = $webp_path;
                $file['type'] = 'image/webp';
                $file['url'] = str_replace($path_parts['basename'], $path_parts['filename'] . '.webp', $file['url']);
            }
        }
        
        return $file;
    }
    
    /**
     * İçerikteki resimleri WebP ile değiştir
     */
    public function replace_images_with_webp($content) {
        // WebP önceliği aktif değilse işlem yapma
        if ($this->get_setting('webp_priority', 'yes') !== 'yes') {
            return $content;
        }
        
        // İçerikteki tüm resimleri bul
        $pattern = '/<img[^>]+src=[\'"]([^\'"]+)[\'"][^>]*>/i';
        
        // Resimleri WebP ile değiştir
        $content = preg_replace_callback($pattern, function($matches) {
            $src = $matches[1];
            
            // Dosya uzantısını kontrol et
            $path_parts = pathinfo($src);
            $extension = isset($path_parts['extension']) ? strtolower($path_parts['extension']) : '';
            
            // Dönüştürülecek uzantıları al
            $allowed_extensions = $this->get_setting('image_formats', array('jpg', 'jpeg', 'png', 'gif'));
            
            // Uzantı dönüştürme listesinde değilse işlem yapma
            if (!in_array($extension, $allowed_extensions)) {
                return $matches[0];
            }
            
            // WebP dosya yolunu oluştur
            $webp_src = $path_parts['dirname'] . '/' . $path_parts['filename'] . '.webp';
            
            // Dosya sunucuda var mı kontrol et
            $webp_path = str_replace(site_url(), ABSPATH, $webp_src);
            
            if (file_exists($webp_path)) {
                // WebP dosyası varsa src'yi değiştir
                return str_replace($src, $webp_src, $matches[0]);
            }
            
            return $matches[0];
        }, $content);
        
        return $content;
    }
}

// WebP Helper modülünü başlat
function ar_webp_helper() {
    return AR_WebP_Helper::get_instance();
}

// WebP Helper modülünü çalıştır
ar_webp_helper();
