<?php
/**
 * Plugin Name: Advanced Image Management
 * Plugin URI: http://arajans.com/wordpress/advanced-image-management
 * Description: It automatically converts uploaded images to WebP format, checks hosting compatibility, manages quality settings, and optimizes media files.
 * Version: 1.3.0
 * Author: Şiyar Kendirci
 * Author URI: https://www.arajans.com
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain: advanced-image-management
 * Domain Path: /languages
 */

// Doğrudan erişimi engelle
if (!defined('ABSPATH')) {
    exit;
}

// Eklenti sabitlerini tanımla
define('AWC_PLUGIN_FILE', __FILE__);
define('AWC_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('AWC_PLUGIN_URL', plugin_dir_url(__FILE__));
define('AWC_PLUGIN_BASENAME', plugin_basename(__FILE__));
define('AWC_VERSION', '1.3.0');

// WebP Helper modülünü yükle
require_once AWC_PLUGIN_DIR . 'admin/convert.php';

// Eklenti sınıfı
class Auto_WebP_Converter {
    
    // Singleton örneği
    private static $instance = null;
    
    /**
     * Singleton örneği döndürür
     */
    public static function get_instance() {
        if (null === self::$instance) {
            self::$instance = new self();
        }
        return self::$instance;
    }
    
    /**
     * Yapılandırıcı
     */
    private function __construct() {
        // Dil desteğini yükle
        $this->load_textdomain();
        
        // Admin menülerini yükle
        if (is_admin()) {
            require_once AWC_PLUGIN_DIR . 'admin/admin-loader.php';
        }
        
        // Kancaları ekle
        $this->add_hooks();
    }
    
    /**
     * Dil dosyalarını yükler
     */
    private function load_textdomain() {
        load_plugin_textdomain('advanced-image-management', false, dirname(plugin_basename(__FILE__)) . '/languages');
    }
    
    /**
     * Kancaları ekler
     */
    private function add_hooks() {
        // Eklenti etkinleştirildiğinde
        register_activation_hook(AWC_PLUGIN_FILE, array($this, 'activate'));
        
        // Eklenti devre dışı bırakıldığında
        register_deactivation_hook(AWC_PLUGIN_FILE, array($this, 'deactivate'));
        
        // Eklenti bağlantıları
        add_filter('plugin_action_links_' . AWC_PLUGIN_BASENAME, array($this, 'add_plugin_links'));
        
        // Medya kütüphanesi işlemleri
        add_action('admin_enqueue_scripts', array($this, 'enqueue_admin_scripts'));
        
        // AJAX işleyicileri
        add_action('wp_ajax_awc_convert_existing', array($this, 'ajax_convert_existing'));
        add_action('wp_ajax_awc_check_hosting', array($this, 'ajax_check_hosting'));
        add_action('wp_ajax_awc_get_directory_structure', array($this, 'ajax_get_directory_structure'));
        add_action('wp_ajax_awc_analyze_directory', array($this, 'ajax_analyze_directory'));
        add_action('wp_ajax_awc_delete_image_sizes', array($this, 'ajax_delete_image_sizes'));
        add_action('wp_ajax_awc_get_statistics', array($this, 'ajax_get_statistics'));
        add_action('wp_ajax_awc_delete_original_images', array($this, 'ajax_delete_original_images'));
        add_action('wp_ajax_awc_get_image_variations', array($this, 'ajax_get_image_variations'));
        add_action('wp_ajax_awc_delete_selected_variation_categories', array($this, 'ajax_delete_selected_variation_categories'));
        
        // Yeni AJAX işleyicileri
        add_action('wp_ajax_awc_get_upload_folders', array($this, 'ajax_get_upload_folders'));
        add_action('wp_ajax_awc_resize_images_in_folder', array($this, 'ajax_resize_images_in_folder'));
        add_action('wp_ajax_awc_convert_images_to_webp_in_folder', array($this, 'ajax_convert_images_to_webp_in_folder'));
        add_action('wp_ajax_awc_analyze_folder_for_resize', array($this, 'ajax_analyze_folder_for_resize'));
        add_action('wp_ajax_awc_analyze_folder_for_webp', array($this, 'ajax_analyze_folder_for_webp'));
        add_action('wp_ajax_awc_get_overall_statistics', array($this, 'ajax_get_overall_statistics'));
        
        // Resim boyutlarını kontrol et
        add_filter('intermediate_image_sizes_advanced', array($this, 'filter_image_sizes'), 10, 2);
        
        // WebP'yi her yerde göster
        add_filter('wp_get_attachment_image_src', array($this, 'filter_attachment_image_src'), 10, 4);
        add_filter('wp_calculate_image_srcset', array($this, 'filter_image_srcset'), 10, 5);
        add_filter('the_content', array($this, 'filter_html_content'), 10, 1);
        add_filter('post_thumbnail_html', array($this, 'filter_html_content'), 10, 1);
        add_filter('get_avatar', array($this, 'filter_html_content'), 10, 1);
        add_filter('widget_text', array($this, 'filter_html_content'), 10, 1);
    }
    
    /**
     * Eklenti etkinleştirildiğinde çalışır
     */
    public function activate() {
        // Varsayılan ayarları ekle
        $default_settings = array(
            'convert_new_uploads' => 'yes',
            'convert_existing' => 'no',
            'keep_original' => 'yes',
            'image_formats' => array('jpg', 'jpeg', 'png'),
            'webp_quality' => 80,
            'hosting_compatible' => 'unknown',
            'only_original_size' => 'no',
            'skip_original_upload' => 'no',
            'upload_quality' => 90,
            'custom_sizes' => array(),
            'webp_priority' => 'yes',
            'statistics' => array(
                'original_size' => 0,
                'converted_size' => 0,
                'saved_size' => 0,
                'converted_count' => 0,
                'deleted_count' => 0,
                'last_update' => 0
            ),
            // Yeni ayarlar
            'original_image_width' => 0, // 0 = orijinal boyutu koru
            'original_image_height' => 0, // 0 = orijinal boyutu koru
            'webp_image_width' => 0, // 0 = orijinal boyutu koru
            'webp_image_height' => 0, // 0 = orijinal boyutu koru
        );
        
        // Eğer ayarlar yoksa varsayılanları ekle
        if (!get_option('awc_settings')) {
            update_option('awc_settings', $default_settings);
        }
    }
    
    /**
     * Eklenti devre dışı bırakıldığında çalışır
     */
    public function deactivate() {
        // Temizlik işlemleri burada yapılabilir
    }
    
    /**
     * Admin scriptlerini ve stillerini ekler
     */
    public function enqueue_admin_scripts($hook) {
        // Sadece eklenti sayfalarında yükle
        if (strpos($hook, 'advanced-image-management') === false) {
            return;
        }
        
        wp_enqueue_style('awc-admin-css', AWC_PLUGIN_URL . 'assets/css/admin.css', array(), AWC_VERSION);
        wp_enqueue_script('awc-admin-js', AWC_PLUGIN_URL . 'assets/js/admin.js', array('jquery'), AWC_VERSION, true);
        
        wp_localize_script('awc-admin-js', 'awc_vars', array(
            'ajax_url' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('awc_nonce'),
            'strings' => array(
                'confirm_delete' => __('Bu işlem geri alınamaz! Devam etmek istediğinize emin misiniz?', 'advanced-image-management'),
                'success' => __('İşlem başarıyla tamamlandı!', 'advanced-image-management'),
                'error' => __('İşlem sırasında bir hata oluştu!', 'advanced-image-management')
            )
        ));
    }
    
    /**
     * Eklenti bağlantılarını ekler
     */
    public function add_plugin_links($links) {
        $plugin_links = array(
            '<a href="' . admin_url('admin.php?page=advanced-image-management') . '">' . __('Ayarlar', 'advanced-image-management') . '</a>'
        );
        
        return array_merge($plugin_links, $links);
    }
    
    /**
     * Ayarları doğrular
     */
    public static function sanitize_settings($input) {
        // Mevcut ayarları al
        $current_settings = get_option('awc_settings', array());
        
        // Hangi ayarlar sayfasından geldiğini belirle
        $is_image_settings = isset($_POST['option_page']) && $_POST['option_page'] === 'awc_image_settings_group';
        $is_webp_settings = isset($_POST['option_page']) && $_POST['option_page'] === 'awc_webp_settings_group';
        $is_dimensions_settings = isset($_POST['option_page']) && $_POST['option_page'] === 'awc_dimensions_settings_group';
        
        // Mevcut ayarları koru, sadece gönderilen ayarları güncelle
        $sanitized = $current_settings;
        
        // Resim Ayarları sayfasından gelen ayarlar
        if ($is_image_settings) {
            // Sadece orijinal boyutu yükle
            $sanitized['only_original_size'] = isset($input['only_original_size']) ? 'yes' : 'no';
            
            // Orijinal resmi yükleme
            $sanitized['skip_original_upload'] = isset($input['skip_original_upload']) ? 'yes' : 'no';
            
            // Yükleme kalitesi
            if (isset($input['upload_quality'])) {
                $sanitized['upload_quality'] = intval($input['upload_quality']);
                // Kalite değerini 0-100 arasında sınırla
                $sanitized['upload_quality'] = max(0, min(100, $sanitized['upload_quality']));
            }
            
            // Özel boyutlar
            if (isset($input['custom_sizes'])) {
                $sanitized['custom_sizes'] = $input['custom_sizes'];
            }
        }
        
        // WebP Ayarları sayfasından gelen ayarlar
        if ($is_webp_settings) {
            // Yeni yüklemeleri dönüştürme
            $sanitized['convert_new_uploads'] = isset($input['convert_new_uploads']) ? 'yes' : 'no';
            
            // Mevcut resimleri dönüştürme
            $sanitized['convert_existing'] = isset($input['convert_existing']) ? 'yes' : 'no';
            
            // Orijinal resimleri saklama
            $sanitized['keep_original'] = isset($input['keep_original']) ? 'yes' : 'no';
            
            // Dönüştürülecek resim formatları
            if (isset($input['image_formats'])) {
                $sanitized['image_formats'] = $input['image_formats'];
            }
            
            // WebP kalitesi
            if (isset($input['webp_quality'])) {
                $sanitized['webp_quality'] = intval($input['webp_quality']);
                // Kalite değerini 0-100 arasında sınırla
                $sanitized['webp_quality'] = max(0, min(100, $sanitized['webp_quality']));
            }
            
            // WebP önceliği
            $sanitized['webp_priority'] = isset($input['webp_priority']) ? 'yes' : 'no';
            
            // Hosting uyumluluğu
            if (isset($input['hosting_compatible'])) {
                $sanitized['hosting_compatible'] = sanitize_text_field($input['hosting_compatible']);
            }
        }
        
        // Boyut ve Kalite Ayarları sayfasından gelen ayarlar
        if ($is_dimensions_settings) {
            // Sadece orijinal boyutu yükle
            $sanitized['only_original_size'] = isset($input['only_original_size']) ? 'yes' : 'no';
            
            // Orijinal resim genişliği
            if (isset($input['original_image_width'])) {
                $sanitized['original_image_width'] = intval($input['original_image_width']);
                // Negatif değerleri engelle
                $sanitized['original_image_width'] = max(0, $sanitized['original_image_width']);
            }
            
            // Orijinal resim yüksekliği
            if (isset($input['original_image_height'])) {
                $sanitized['original_image_height'] = intval($input['original_image_height']);
                // Negatif değerleri engelle
                $sanitized['original_image_height'] = max(0, $sanitized['original_image_height']);
            }
            
            // WebP resim genişliği
            if (isset($input['webp_image_width'])) {
                $sanitized['webp_image_width'] = intval($input['webp_image_width']);
                // Negatif değerleri engelle
                $sanitized['webp_image_width'] = max(0, $sanitized['webp_image_width']);
            }
            
            // WebP resim yüksekliği
            if (isset($input['webp_image_height'])) {
                $sanitized['webp_image_height'] = intval($input['webp_image_height']);
                // Negatif değerleri engelle
                $sanitized['webp_image_height'] = max(0, $sanitized['webp_image_height']);
            }
            
            // Yükleme kalitesi
            if (isset($input['upload_quality'])) {
                $sanitized['upload_quality'] = intval($input['upload_quality']);
                // Kalite değerini 0-100 arasında sınırla
                $sanitized['upload_quality'] = max(0, min(100, $sanitized['upload_quality']));
            }
            
            // WebP kalitesi
            if (isset($input['webp_quality'])) {
                $sanitized['webp_quality'] = intval($input['webp_quality']);
                // Kalite değerini 0-100 arasında sınırla
                $sanitized['webp_quality'] = max(0, min(100, $sanitized['webp_quality']));
            }
        }
        
        // Varsayılan değerleri ayarla (ilk kurulum için)
        if (!isset($sanitized['convert_new_uploads'])) {
            $sanitized['convert_new_uploads'] = 'yes';
        }
        
        if (!isset($sanitized['convert_existing'])) {
            $sanitized['convert_existing'] = 'no';
        }
        
        if (!isset($sanitized['keep_original'])) {
            $sanitized['keep_original'] = 'yes';
        }
        
        if (!isset($sanitized['image_formats'])) {
            $sanitized['image_formats'] = array('jpg', 'jpeg', 'png');
        }
        
        if (!isset($sanitized['webp_quality'])) {
            $sanitized['webp_quality'] = 80;
        }
        
        if (!isset($sanitized['hosting_compatible'])) {
            $sanitized['hosting_compatible'] = 'unknown';
        }
        
        if (!isset($sanitized['only_original_size'])) {
            $sanitized['only_original_size'] = 'no';
        }
        
        if (!isset($sanitized['skip_original_upload'])) {
            $sanitized['skip_original_upload'] = 'no';
        }
        
        if (!isset($sanitized['upload_quality'])) {
            $sanitized['upload_quality'] = 90;
        }
        
        if (!isset($sanitized['webp_priority'])) {
            $sanitized['webp_priority'] = 'yes';
        }
        
        if (!isset($sanitized['original_image_width'])) {
            $sanitized['original_image_width'] = 0;
        }
        
        if (!isset($sanitized['original_image_height'])) {
            $sanitized['original_image_height'] = 0;
        }
        
        if (!isset($sanitized['webp_image_width'])) {
            $sanitized['webp_image_width'] = 0;
        }
        
        if (!isset($sanitized['webp_image_height'])) {
            $sanitized['webp_image_height'] = 0;
        }
        
        return $sanitized;
    }
    
    /**
     * Resim boyutlarını filtreler
     */
    public function filter_image_sizes($sizes, $metadata) {
        // Ayarları al
        $settings = get_option('awc_settings', array());
        
        // Sadece orijinal boyutu yükle seçeneği etkinse
        if (isset($settings['only_original_size']) && $settings['only_original_size'] === 'yes') {
            return array();
        }
        
        return $sizes;
    }
    
    /**
     * Resim src'sini filtreler
     */
    public function filter_attachment_image_src($image, $attachment_id, $size, $icon) {
        // Ayarları al
        $settings = get_option('awc_settings', array());
        
        // WebP önceliği etkinse
        if (isset($settings['webp_priority']) && $settings['webp_priority'] === 'yes') {
            // WebP versiyonunu kontrol et ve varsa kullan
            if (is_array($image) && isset($image[0])) {
                $image_url = $image[0];
                $path_parts = pathinfo($image_url);
                
                if (isset($path_parts['extension'])) {
                    $extension = strtolower($path_parts['extension']);
                    $allowed_extensions = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png');
                    
                    if (in_array($extension, $allowed_extensions)) {
                        $webp_url = $path_parts['dirname'] . '/' . $path_parts['filename'] . '.webp';
                        $webp_path = str_replace(site_url(), ABSPATH, $webp_url);
                        
                        if (file_exists($webp_path)) {
                            $image[0] = $webp_url;
                            $image['mime-type'] = 'image/webp';
                        }
                    }
                }
            }
        }
        
        return $image;
    }
    
    /**
     * Resim srcset'ini filtreler
     */
    public function filter_image_srcset($sources, $size_array, $image_src, $image_meta, $attachment_id) {
        // Ayarları al
        $settings = get_option('awc_settings', array());
        
        // WebP önceliği etkinse
        if (isset($settings['webp_priority']) && $settings['webp_priority'] === 'yes') {
            // WebP versiyonlarını kontrol et ve varsa kullan
            if (is_array($sources)) {
                foreach ($sources as $width => $source) {
                    if (isset($source['url'])) {
                        $image_url = $source['url'];
                        $path_parts = pathinfo($image_url);
                        
                        if (isset($path_parts['extension'])) {
                            $extension = strtolower($path_parts['extension']);
                            $allowed_extensions = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png');
                            
                            if (in_array($extension, $allowed_extensions)) {
                                $webp_url = $path_parts['dirname'] . '/' . $path_parts['filename'] . '.webp';
                                $webp_path = str_replace(site_url(), ABSPATH, $webp_url);
                                
                                if (file_exists($webp_path)) {
                                    $sources[$width]['url'] = $webp_url;
                                    $sources[$width]['mime-type'] = 'image/webp';
                                }
                            }
                        }
                    }
                }
            }
        }
        
        return $sources;
    }
    
    /**
     * HTML içeriğini filtreler
     */
    public function filter_html_content($content) {
        // Ayarları al
        $settings = get_option('awc_settings', array());
        
        // WebP önceliği etkinse
        if (isset($settings['webp_priority']) && $settings['webp_priority'] === 'yes') {
            // HTML içeriğindeki resimleri WebP versiyonlarıyla değiştir
            $pattern = '/<img[^>]+src=[\'"]([^\'"]+)[\'"][^>]*>/i';
            
            $content = preg_replace_callback($pattern, function($matches) use ($settings) {
                $src = $matches[1];
                $path_parts = pathinfo($src);
                
                if (isset($path_parts['extension'])) {
                    $extension = strtolower($path_parts['extension']);
                    $allowed_extensions = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png');
                    
                    if (in_array($extension, $allowed_extensions)) {
                        $webp_src = $path_parts['dirname'] . '/' . $path_parts['filename'] . '.webp';
                        $webp_path = str_replace(site_url(), ABSPATH, $webp_src);
                        
                        if (file_exists($webp_path)) {
                            return str_replace($src, $webp_src, $matches[0]);
                        }
                    }
                }
                
                return $matches[0];
            }, $content);
        }
        
        return $content;
    }
    
    /**
     * AJAX: Mevcut resimleri dönüştür
     */
    public function ajax_convert_existing() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_convert_existing', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Ayarları al
        $settings = get_option('awc_settings', array());
        
        // Dönüştürülecek formatları al
        $allowed_extensions = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png');
        
        // WebP kalitesini al
        $quality = isset($settings['webp_quality']) ? intval($settings['webp_quality']) : 80;
        
        // WebP resim boyutlarını al
        $webp_width = isset($settings['webp_image_width']) ? intval($settings['webp_image_width']) : 0;
        $webp_height = isset($settings['webp_image_height']) ? intval($settings['webp_image_height']) : 0;
        
        // Upload dizinini al
        $upload_dir = wp_upload_dir();
        $base_dir = $upload_dir['basedir'];
        
        // Dönüştürülen resim sayısı
        $converted_count = 0;
        $original_size = 0;
        $converted_size = 0;
        
        // Dizindeki dosyaları tara
        $files = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($base_dir, RecursiveDirectoryIterator::SKIP_DOTS),
            RecursiveIteratorIterator::SELF_FIRST,
            RecursiveIteratorIterator::CATCH_GET_CHILD
        );
        
        foreach ($files as $file) {
            if ($file->isFile()) {
                $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                
                if (in_array($extension, $allowed_extensions)) {
                    $webp_file = pathinfo($file->getPathname(), PATHINFO_DIRNAME) . '/' . pathinfo($file->getPathname(), PATHINFO_FILENAME) . '.webp';
                    
                    // WebP dosyası yoksa veya orijinal dosyadan daha eskiyse dönüştür
                    if (!file_exists($webp_file) || filemtime($webp_file) < filemtime($file->getPathname())) {
                        // GD kütüphanesi ile WebP dönüştürme
                        if (function_exists('imagewebp')) {
                            // Kaynak resmi yükle
                            $image = null;
                            
                            switch ($extension) {
                                case 'jpg':
                                case 'jpeg':
                                    $image = @imagecreatefromjpeg($file->getPathname());
                                    break;
                                case 'png':
                                    $image = @imagecreatefrompng($file->getPathname());
                                    // PNG şeffaflığını koru
                                    if ($image) {
                                        imagepalettetotruecolor($image);
                                        imagealphablending($image, true);
                                        imagesavealpha($image, true);
                                    }
                                    break;
                                case 'gif':
                                    $image = @imagecreatefromgif($file->getPathname());
                                    break;
                            }
                            
                            // Resim yüklenemediyse devam et
                            if (!$image) {
                                continue;
                            }
                            
                            // WebP için yeniden boyutlandırma
                            if ($webp_width > 0 && $webp_height > 0) {
                                $orig_width = imagesx($image);
                                $orig_height = imagesy($image);
                                
                                $webp_image = imagecreatetruecolor($webp_width, $webp_height);
                                
                                // PNG şeffaflığını koru
                                if ($extension == 'png') {
                                    imagealphablending($webp_image, false);
                                    imagesavealpha($webp_image, true);
                                    $transparent = imagecolorallocatealpha($webp_image, 255, 255, 255, 127);
                                    imagefilledrectangle($webp_image, 0, 0, $webp_width, $webp_height, $transparent);
                                }
                                
                                // Yeniden boyutlandır
                                imagecopyresampled($webp_image, $image, 0, 0, 0, 0, $webp_width, $webp_height, $orig_width, $orig_height);
                                
                                // Eski resmi serbest bırak
                                imagedestroy($image);
                                $image = $webp_image;
                            }
                            
                            // WebP olarak kaydet
                            imagewebp($image, $webp_file, $quality);
                            
                            // Belleği temizle
                            imagedestroy($image);
                            
                            // İstatistikleri güncelle
                            $converted_count++;
                            $original_size += $file->getSize();
                            $converted_size += filesize($webp_file);
                        }
                    } else {
                        // İstatistikleri güncelle
                        $original_size += $file->getSize();
                        $converted_size += filesize($webp_file);
                    }
                }
            }
        }
        
        // İstatistikleri güncelle
        $statistics = isset($settings['statistics']) ? $settings['statistics'] : array(
            'original_size' => 0,
            'converted_size' => 0,
            'saved_size' => 0,
            'converted_count' => 0,
            'deleted_count' => 0,
            'last_update' => 0
        );
        
        $statistics['original_size'] = $original_size;
        $statistics['converted_size'] = $converted_size;
        $statistics['saved_size'] = $original_size - $converted_size;
        $statistics['converted_count'] = $converted_count;
        $statistics['last_update'] = time();
        
        $settings['statistics'] = $statistics;
        update_option('awc_settings', $settings);
        
        wp_send_json_success(array(
		/* translators: %s: İşlem sonucunu gösterir */
            'message' => sprintf(__('%d resim başarıyla dönüştürüldü!', 'advanced-image-management'), $converted_count),
            'converted_count' => $converted_count
        ));
    }
    
    /**
     * AJAX: Hosting uyumluluğunu kontrol et
     */
    public function ajax_check_hosting() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_check_hosting', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Uyumluluk kontrolü
        $compatible = function_exists('imagewebp');
        
        // Ayarları güncelle
        $settings = get_option('awc_settings', array());
        $settings['hosting_compatible'] = $compatible ? 'yes' : 'no';
        update_option('awc_settings', $settings);
        
        wp_send_json_success(array('compatible' => $compatible));
    }
    
    /**
     * AJAX: Dizin yapısını al
     */
    public function ajax_get_directory_structure() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_get_directory_structure', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Dizin yapısını al
        $upload_dir = wp_upload_dir();
        $base_dir = $upload_dir['basedir'];
        
        $directories = array();
        
        // Ana dizinleri al
        $main_dirs = glob($base_dir . '/*', GLOB_ONLYDIR);
        
        foreach ($main_dirs as $dir) {
            $dir_name = basename($dir);
            
            // Alt dizinleri al
            $sub_dirs = glob($dir . '/*', GLOB_ONLYDIR);
            $subdirectories = array();
            
            foreach ($sub_dirs as $sub_dir) {
                $subdirectories[] = array(
                    'name' => basename($sub_dir),
                    'path' => str_replace($base_dir, '', $sub_dir)
                );
            }
            
            $directories[] = array(
                'name' => $dir_name,
                'path' => str_replace($base_dir, '', $dir),
                'subdirectories' => $subdirectories
            );
        }
        
        wp_send_json_success(array('directories' => $directories));
    }
    
    /**
     * AJAX: Dizini analiz et
     */
    public function ajax_analyze_directory() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_analyze_directory', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Dizin yolunu al
        $directory = isset($_POST['directory']) ? sanitize_text_field($_POST['directory']) : '';
        
        if (empty($directory)) {
            wp_send_json_error(array('message' => __('Geçersiz dizin!', 'advanced-image-management')));
        }
        
        // Dizini analiz et
        $upload_dir = wp_upload_dir();
        $base_dir = $upload_dir['basedir'];
        $full_dir = $base_dir . $directory;
        
        // Dizin var mı kontrol et
        if (!is_dir($full_dir)) {
            wp_send_json_error(array('message' => __('Dizin bulunamadı!', 'advanced-image-management')));
        }
        
        // Resimleri say
        $total_images = 0;
        $converted_images = 0;
        $total_size = 0;
        $webp_size = 0;
        
        // Resim formatları
        $settings = get_option('awc_settings', array());
        $image_formats = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png', 'gif');
        
        // Dizindeki dosyaları tara
        $files = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($full_dir, RecursiveDirectoryIterator::SKIP_DOTS),
            RecursiveIteratorIterator::SELF_FIRST,
            RecursiveIteratorIterator::CATCH_GET_CHILD
        );
        
        foreach ($files as $file) {
            if ($file->isFile()) {
                $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                
                if (in_array($extension, $image_formats)) {
                    $total_images++;
                    $total_size += $file->getSize();
                    
                    // WebP versiyonu var mı kontrol et
                    $webp_file = pathinfo($file->getPathname(), PATHINFO_DIRNAME) . '/' . pathinfo($file->getPathname(), PATHINFO_FILENAME) . '.webp';
                    
                    if (file_exists($webp_file)) {
                        $converted_images++;
                        $webp_size += filesize($webp_file);
                    }
                }
            }
        }
        
        // Tasarruf hesapla
        $saved_size = $total_size - $webp_size;
        $saved_percentage = $total_size > 0 ? round(($saved_size / $total_size) * 100, 2) : 0;
        
        wp_send_json_success(array(
            'total_images' => $total_images,
            'converted_images' => $converted_images,
            'not_converted_images' => $total_images - $converted_images,
            'total_size' => size_format($total_size),
            'webp_size' => size_format($webp_size),
            'saved_size' => size_format($saved_size) . ' (' . $saved_percentage . '%)'
        ));
    }
    
    /**
     * AJAX: Resim boyutlarını sil
     */
    public function ajax_delete_image_sizes() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_delete_image_sizes', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Upload dizinini al
        $upload_dir = wp_upload_dir();
        $base_dir = $upload_dir['basedir'];
        
        // Silinen resim sayısı
        $deleted_count = 0;
        $saved_size = 0;
        
        // WordPress'in oluşturduğu boyutları al
        $image_sizes = get_intermediate_image_sizes();
        
        // Medya kütüphanesindeki resimleri al
        $args = array(
            'post_type' => 'attachment',
            'post_mime_type' => 'image',
            'post_status' => 'inherit',
            'posts_per_page' => -1,
        );
        
        $query = new WP_Query($args);
        
        if ($query->have_posts()) {
            while ($query->have_posts()) {
                $query->the_post();
                $attachment_id = get_the_ID();
                
                // Resim meta verilerini al
                $metadata = wp_get_attachment_metadata($attachment_id);
                
                if (isset($metadata['file'])) {
                    $file_path = $base_dir . '/' . $metadata['file'];
                    $dir_path = dirname($file_path);
                    
                    // Resim boyutlarını sil
                    if (isset($metadata['sizes'])) {
                        foreach ($metadata['sizes'] as $size => $size_info) {
                            if (isset($size_info['file'])) {
                                $size_file = $dir_path . '/' . $size_info['file'];
                                
                                if (file_exists($size_file)) {
                                    $saved_size += filesize($size_file);
                                    unlink($size_file);
                                    $deleted_count++;
                                }
                                
                                // WebP versiyonunu da sil
                                $webp_file = $dir_path . '/' . pathinfo($size_info['file'], PATHINFO_FILENAME) . '.webp';
                                
                                if (file_exists($webp_file)) {
                                    $saved_size += filesize($webp_file);
                                    unlink($webp_file);
                                    $deleted_count++;
                                }
                            }
                        }
                        
                        // Meta verileri güncelle
                        $metadata['sizes'] = array();
                        wp_update_attachment_metadata($attachment_id, $metadata);
                    }
                }
            }
            
            wp_reset_postdata();
        }
        
        // İstatistikleri güncelle
        $settings = get_option('awc_settings', array());
        $statistics = isset($settings['statistics']) ? $settings['statistics'] : array(
            'original_size' => 0,
            'converted_size' => 0,
            'saved_size' => 0,
            'converted_count' => 0,
            'deleted_count' => 0,
            'last_update' => 0
        );
        
        $statistics['deleted_count'] += $deleted_count;
        $statistics['saved_size'] += $saved_size;
        $statistics['last_update'] = time();
        
        $settings['statistics'] = $statistics;
        update_option('awc_settings', $settings);
        
        wp_send_json_success(array(
		/* translators: %s: İşlem sonucunu gösterir - Resim silindi */
            'message' => sprintf(__('%d resim boyutu başarıyla silindi!', 'advanced-image-management'), $deleted_count),
            'deleted_count' => $deleted_count,
            'saved_size' => size_format($saved_size)
        ));
    }
    
    /**
     * AJAX: İstatistikleri al
     */
    public function ajax_get_statistics() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_get_statistics', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // İstatistikleri hesapla
        $upload_dir = wp_upload_dir();
        $base_dir = $upload_dir['basedir'];
        
        $total_images = 0;
        $converted_images = 0;
        $total_size = 0;
        $webp_size = 0;
        
        // Resim formatları
        $settings = get_option('awc_settings', array());
        $image_formats = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png', 'gif');
        
        // Dizindeki dosyaları tara
        $files = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($base_dir, RecursiveDirectoryIterator::SKIP_DOTS),
            RecursiveIteratorIterator::SELF_FIRST,
            RecursiveIteratorIterator::CATCH_GET_CHILD
        );
        
        foreach ($files as $file) {
            if ($file->isFile()) {
                $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                
                if (in_array($extension, $image_formats)) {
                    $total_images++;
                    $total_size += $file->getSize();
                    
                    // WebP versiyonu var mı kontrol et
                    $webp_file = pathinfo($file->getPathname(), PATHINFO_DIRNAME) . '/' . pathinfo($file->getPathname(), PATHINFO_FILENAME) . '.webp';
                    
                    if (file_exists($webp_file)) {
                        $converted_images++;
                        $webp_size += filesize($webp_file);
                    }
                }
            }
        }
        
        // Tasarruf hesapla
        $saved_size = $total_size - $webp_size;
        
        // İstatistikleri güncelle
        $statistics = isset($settings['statistics']) ? $settings['statistics'] : array(
            'original_size' => 0,
            'converted_size' => 0,
            'saved_size' => 0,
            'converted_count' => 0,
            'deleted_count' => 0,
            'last_update' => 0
        );
        
        $statistics['original_size'] = $total_size;
        $statistics['converted_size'] = $webp_size;
        $statistics['saved_size'] = $saved_size;
        $statistics['converted_count'] = $converted_images;
        $statistics['last_update'] = time();
        
        $settings['statistics'] = $statistics;
        update_option('awc_settings', $settings);
        
        $saved_percentage = $total_size > 0 ? round(($saved_size / $total_size) * 100, 2) : 0;
        
        wp_send_json_success(array(
            'total_images' => $total_images,
            'converted_images' => $converted_images,
            'not_converted_images' => $total_images - $converted_images,
            'total_size' => size_format($total_size),
            'webp_size' => size_format($webp_size),
            'saved_size' => size_format($saved_size) . ' (' . $saved_percentage . '%)'
        ));
    }
    
    /**
     * AJAX: Orijinal resimleri sil
     */
    public function ajax_delete_original_images() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_delete_original_images', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        try {
            // Upload dizinini al
            $upload_dir = wp_upload_dir();
            $base_dir = $upload_dir['basedir'];
            
            // Silinen resim sayısı
            $deleted_count = 0;
            $saved_size = 0;
            
            // Resim formatları
            $settings = get_option('awc_settings', array());
            $image_formats = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png', 'gif');
            
            // Dizindeki dosyaları tara
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($base_dir, RecursiveDirectoryIterator::SKIP_DOTS),
                RecursiveIteratorIterator::SELF_FIRST,
                RecursiveIteratorIterator::CATCH_GET_CHILD
            );
            
            foreach ($files as $file) {
                if ($file->isFile()) {
                    $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                    
                    if (in_array($extension, $image_formats)) {
                        // WebP versiyonu var mı kontrol et
                        $webp_file = pathinfo($file->getPathname(), PATHINFO_DIRNAME) . '/' . pathinfo($file->getPathname(), PATHINFO_FILENAME) . '.webp';
                        
                        if (file_exists($webp_file)) {
                            // Dosya izinlerini kontrol et
                            if (!is_writable($file->getPathname())) {
                                chmod($file->getPathname(), 0644);
                            }
                            
                            // Orijinal dosyayı sil
                            if (unlink($file->getPathname())) {
                                $saved_size += $file->getSize();
                                $deleted_count++;
                            }
                        }
                    }
                }
            }
            
            // İstatistikleri güncelle
            $statistics = isset($settings['statistics']) ? $settings['statistics'] : array(
                'original_size' => 0,
                'converted_size' => 0,
                'saved_size' => 0,
                'converted_count' => 0,
                'deleted_count' => 0,
                'last_update' => 0
            );
            
            $statistics['deleted_count'] += $deleted_count;
            $statistics['saved_size'] += $saved_size;
            $statistics['last_update'] = time();
            
            $settings['statistics'] = $statistics;
            update_option('awc_settings', $settings);
            
            wp_send_json_success(array(
			/* translators: %s: İşlem sonucunu gösterir */
                'message' => sprintf(__('%d orijinal resim başarıyla silindi!', 'advanced-image-management'), $deleted_count),
                'deleted_count' => $deleted_count,
                'saved_size' => size_format($saved_size)
            ));
        } catch (Exception $e) {
            wp_send_json_error(array(
                'message' => __('Orijinal resimler silinirken bir hata oluştu!', 'advanced-image-management'),
                'error' => $e->getMessage()
            ));
        }
    }
    
    /**
     * AJAX: Resim varyasyonlarını al
     */
    public function ajax_get_image_variations() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_get_image_variations', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Upload dizinini al
        $upload_dir = wp_upload_dir();
        $base_dir = $upload_dir['basedir'];
        
        // Resim varyasyonları
        $variations = array();
        
        // Resim formatları
        $settings = get_option('awc_settings', array());
        $image_formats = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png', 'gif');
        
        // WordPress'in oluşturduğu boyutları al
        $image_sizes = get_intermediate_image_sizes();
        
        // Varyasyon kategorilerini oluştur
        $variations['original'] = array(
            'name' => __('Orijinal Resimler', 'advanced-image-management'),
            'count' => 0,
            'size' => 0,
            'files' => array()
        );
        
        $variations['webp'] = array(
            'name' => __('WebP Dönüşümleri', 'advanced-image-management'),
            'count' => 0,
            'size' => 0,
            'files' => array()
        );
        
        foreach ($image_sizes as $size) {
            $variations[$size] = array(
			/* translators: %s: İşlem sonucunu gösterir */
                'name' => sprintf(__('%s Boyutu', 'advanced-image-management'), ucfirst($size)),
                'count' => 0,
                'size' => 0,
                'files' => array()
            );
            
            $variations[$size . '_webp'] = array(
			/* translators: %s: Boyut ayarı gösterir */
                'name' => sprintf(__('%s Boyutu WebP', 'advanced-image-management'), ucfirst($size)),
                'count' => 0,
                'size' => 0,
                'files' => array()
            );
        }
        
        // Medya kütüphanesindeki resimleri al
        $args = array(
            'post_type' => 'attachment',
            'post_mime_type' => 'image',
            'post_status' => 'inherit',
            'posts_per_page' => -1,
        );
        
        $query = new WP_Query($args);
        
        if ($query->have_posts()) {
            while ($query->have_posts()) {
                $query->the_post();
                $attachment_id = get_the_ID();
                
                // Resim meta verilerini al
                $metadata = wp_get_attachment_metadata($attachment_id);
                
                if (isset($metadata['file'])) {
                    $file_path = $base_dir . '/' . $metadata['file'];
                    
                    // Dosya gerçekten var mı kontrol et
                    if (file_exists($file_path)) {
                        $dir_path = dirname($file_path);
                        $file_name = basename($file_path);
                        $extension = strtolower(pathinfo($file_path, PATHINFO_EXTENSION));
                        
                        // Orijinal resim
                        if (in_array($extension, $image_formats)) {
                            $original_size = filesize($file_path);
                            $variations['original']['count']++;
                            $variations['original']['size'] += $original_size;
                            $variations['original']['files'][] = $file_path;
                            
                            // WebP versiyonu
                            $webp_file = pathinfo($file_path, PATHINFO_DIRNAME) . '/' . pathinfo($file_path, PATHINFO_FILENAME) . '.webp';
                            
                            if (file_exists($webp_file)) {
                                $webp_size = filesize($webp_file);
                                $variations['webp']['count']++;
                                $variations['webp']['size'] += $webp_size;
                                $variations['webp']['files'][] = $webp_file;
                            }
                            
                            // Resim boyutları
                            if (isset($metadata['sizes'])) {
                                foreach ($metadata['sizes'] as $size => $size_info) {
                                    if (isset($size_info['file'])) {
                                        $size_file = $dir_path . '/' . $size_info['file'];
                                        
                                        if (file_exists($size_file)) {
                                            $size_file_size = filesize($size_file);
                                            
                                            if (isset($variations[$size])) {
                                                $variations[$size]['count']++;
                                                $variations[$size]['size'] += $size_file_size;
                                                $variations[$size]['files'][] = $size_file;
                                            }
                                            
                                            // WebP versiyonu
                                            $size_webp_file = $dir_path . '/' . pathinfo($size_info['file'], PATHINFO_FILENAME) . '.webp';
                                            
                                            if (file_exists($size_webp_file)) {
                                                $size_webp_size = filesize($size_webp_file);
                                                $size_webp_key = $size . '_webp';
                                                
                                                if (isset($variations[$size_webp_key])) {
                                                    $variations[$size_webp_key]['count']++;
                                                    $variations[$size_webp_key]['size'] += $size_webp_size;
                                                    $variations[$size_webp_key]['files'][] = $size_webp_file;
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
            
            wp_reset_postdata();
        }
        
        // Boş varyasyonları kaldır
        foreach ($variations as $key => $variation) {
            if ($variation['count'] == 0) {
                unset($variations[$key]);
            }
        }
        
        // Varyasyonları boyuta göre sırala
        uasort($variations, function($a, $b) {
            return $b['size'] - $a['size'];
        });
        
        // Sonuçları gönder
        wp_send_json_success(array(
            'variations' => $variations
        ));
    }
    
    /**
     * AJAX: Seçilen varyasyon kategorilerini sil
     */
    public function ajax_delete_selected_variation_categories() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_delete_selected_variation_categories', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Seçilen kategorileri al
        $selected_categories = isset($_POST['categories']) ? $_POST['categories'] : array();
        
        if (empty($selected_categories)) {
            wp_send_json_error(array('message' => __('Hiçbir kategori seçilmedi!', 'advanced-image-management')));
        }
        
        try {
            // Varyasyon bilgilerini al
            $variations = $this->get_image_variations_data();
            
            // Silinen resim sayısı
            $deleted_count = 0;
            $saved_size = 0;
            
            // Seçilen kategorileri sil
            foreach ($selected_categories as $category) {
                if (isset($variations[$category])) {
                    foreach ($variations[$category]['files'] as $file) {
                        if (file_exists($file)) {
                            // Dosya izinlerini kontrol et
                            if (!is_writable($file)) {
                                chmod($file, 0644);
                            }
                            
                            // Dosyayı sil
                            if (unlink($file)) {
                                $saved_size += filesize($file);
                                $deleted_count++;
                            }
                        }
                    }
                }
            }
            
            // İstatistikleri güncelle
            $settings = get_option('awc_settings', array());
            $statistics = isset($settings['statistics']) ? $settings['statistics'] : array(
                'original_size' => 0,
                'converted_size' => 0,
                'saved_size' => 0,
                'converted_count' => 0,
                'deleted_count' => 0,
                'last_update' => 0
            );
            
            $statistics['deleted_count'] += $deleted_count;
            $statistics['saved_size'] += $saved_size;
            $statistics['last_update'] = time();
            
            $settings['statistics'] = $statistics;
            update_option('awc_settings', $settings);
            
            wp_send_json_success(array(
			/* translators: %s: Resim varyasyon silme sonucunu gösterir */
                'message' => sprintf(__('%d resim varyasyonu başarıyla silindi!', 'advanced-image-management'), $deleted_count),
                'deleted_count' => $deleted_count,
                'saved_size' => size_format($saved_size)
            ));
        } catch (Exception $e) {
            wp_send_json_error(array(
                'message' => __('Resim varyasyonları silinirken bir hata oluştu!', 'advanced-image-management'),
                'error' => $e->getMessage()
            ));
        }
    }
    
    /**
     * AJAX: Upload klasörlerini al
     */
    public function ajax_get_upload_folders() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_get_upload_folders', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Upload dizinini al
        $upload_dir = wp_upload_dir();
        $base_dir = $upload_dir['basedir'];
        
        $folders = array();
        
        // Yıl klasörlerini al (örn: 2023, 2022, ...)
        $year_dirs = glob($base_dir . '/20*', GLOB_ONLYDIR);
        
        foreach ($year_dirs as $year_dir) {
            $year = basename($year_dir);
            
            // Ay klasörlerini al (örn: 01, 02, ...)
            $month_dirs = glob($year_dir . '/*', GLOB_ONLYDIR);
            $months = array();
            
            foreach ($month_dirs as $month_dir) {
                $month = basename($month_dir);
                
                // Sadece sayısal ay klasörlerini al
                if (is_numeric($month) && $month >= 1 && $month <= 12) {
                    $months[] = array(
                        'name' => $month,
                        'path' => '/' . $year . '/' . $month
                    );
                }
            }
            
            $folders[] = array(
                'name' => $year,
                'path' => '/' . $year,
                'months' => $months
            );
        }
        
        wp_send_json_success(array('folders' => $folders));
    }
    
    /**
     * AJAX: Klasördeki resimleri yeniden boyutlandır
     */
    public function ajax_resize_images_in_folder() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_resize_images_in_folder', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Parametreleri al
        $folder = isset($_POST['folder']) ? sanitize_text_field($_POST['folder']) : '';
        $width = isset($_POST['width']) ? intval($_POST['width']) : 0;
        $height = isset($_POST['height']) ? intval($_POST['height']) : 0;
        $quality = isset($_POST['quality']) ? intval($_POST['quality']) : 90;
        $keep_originals = isset($_POST['keep_originals']) && $_POST['keep_originals'] === 'true';
        
        // Parametreleri kontrol et
        if (empty($folder)) {
            wp_send_json_error(array('message' => __('Geçersiz klasör!', 'advanced-image-management')));
        }
        
        if ($width <= 0 && $height <= 0) {
            wp_send_json_error(array('message' => __('Geçersiz boyut değerleri!', 'advanced-image-management')));
        }
        
        // Kalite değerini sınırla
        $quality = max(1, min(100, $quality));
        
        try {
            // Upload dizinini al
            $upload_dir = wp_upload_dir();
            $base_dir = $upload_dir['basedir'];
            $full_dir = $base_dir . $folder;
            
            // Dizin var mı kontrol et
            if (!is_dir($full_dir)) {
                wp_send_json_error(array('message' => __('Dizin bulunamadı!', 'advanced-image-management')));
            }
            
            // İşlem sonuçları
            $processed = 0;
            $success = 0;
            $error = 0;
            $saved_size = 0;
            
            // Resim formatları
            $image_formats = array('jpg', 'jpeg', 'png');
            
            // Dizindeki dosyaları tara
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($full_dir, RecursiveDirectoryIterator::SKIP_DOTS),
                RecursiveIteratorIterator::SELF_FIRST,
                RecursiveIteratorIterator::CATCH_GET_CHILD
            );
            
            foreach ($files as $file) {
                if ($file->isFile()) {
                    $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                    
                    if (in_array($extension, $image_formats)) {
                        $processed++;
                        
                        // Orijinal dosya boyutu
                        $original_size = $file->getSize();
                        
                        // Orijinali yedekle
                        if ($keep_originals) {
                            $backup_file = pathinfo($file->getPathname(), PATHINFO_DIRNAME) . '/' . pathinfo($file->getPathname(), PATHINFO_FILENAME) . '_backup.' . $extension;
                            copy($file->getPathname(), $backup_file);
                        }
                        
                        // GD kütüphanesi ile yeniden boyutlandırma
                        if (function_exists('imagecreatefromjpeg') && function_exists('imagecreatefrompng')) {
                            // Kaynak resmi yükle
                            $image = null;
                            
                            switch ($extension) {
                                case 'jpg':
                                case 'jpeg':
                                    $image = @imagecreatefromjpeg($file->getPathname());
                                    break;
                                case 'png':
                                    $image = @imagecreatefrompng($file->getPathname());
                                    // PNG şeffaflığını koru
                                    if ($image) {
                                        imagepalettetotruecolor($image);
                                        imagealphablending($image, true);
                                        imagesavealpha($image, true);
                                    }
                                    break;
                            }
                            
                            // Resim yüklenemediyse devam et
                            if (!$image) {
                                $error++;
                                continue;
                            }
                            
                            // Orijinal boyutları al
                            $orig_width = imagesx($image);
                            $orig_height = imagesy($image);
                            
                            // Yeni boyutları hesapla
                            $new_width = $width > 0 ? $width : $orig_width;
                            $new_height = $height > 0 ? $height : $orig_height;
                            
                            // Oranları koru
                            if ($width > 0 && $height <= 0) {
                                $new_height = round(($new_width / $orig_width) * $orig_height);
                            } elseif ($width <= 0 && $height > 0) {
                                $new_width = round(($new_height / $orig_height) * $orig_width);
                            }
                            
                            // Yeniden boyutlandırma gerekli mi kontrol et
                            if ($new_width != $orig_width || $new_height != $orig_height) {
                                // Yeni resim oluştur
                                $new_image = imagecreatetruecolor($new_width, $new_height);
                                
                                // PNG şeffaflığını koru
                                if ($extension == 'png') {
                                    imagealphablending($new_image, false);
                                    imagesavealpha($new_image, true);
                                    $transparent = imagecolorallocatealpha($new_image, 255, 255, 255, 127);
                                    imagefilledrectangle($new_image, 0, 0, $new_width, $new_height, $transparent);
                                }
                                
                                // Yeniden boyutlandır
                                imagecopyresampled($new_image, $image, 0, 0, 0, 0, $new_width, $new_height, $orig_width, $orig_height);
                                
                                // Eski resmi serbest bırak
                                imagedestroy($image);
                                $image = $new_image;
                            }
                            
                            // Resmi kaydet
                            $save_result = false;
                            
                            switch ($extension) {
                                case 'jpg':
                                case 'jpeg':
                                    $save_result = imagejpeg($image, $file->getPathname(), $quality);
                                    break;
                                case 'png':
                                    // PNG için kalite 0-9 arasında olmalı
                                    $png_quality = round(9 - (($quality / 100) * 9));
                                    $save_result = imagepng($image, $file->getPathname(), $png_quality);
                                    break;
                            }
                            
                            // Belleği temizle
                            imagedestroy($image);
                            
                            if ($save_result) {
                                $success++;
                                
                                // Kazanılan alanı hesapla
                                $new_size = filesize($file->getPathname());
                                $saved_size += ($original_size - $new_size);
                            } else {
                                $error++;
                            }
                        } else {
                            $error++;
                        }
                    }
                }
            }
            
            wp_send_json_success(array(
                'processed' => $processed,
                'success' => $success,
                'error' => $error,
                'saved_size' => $saved_size
            ));
        } catch (Exception $e) {
            wp_send_json_error(array(
                'message' => __('Resimler yeniden boyutlandırılırken bir hata oluştu!', 'advanced-image-management'),
                'error' => $e->getMessage()
            ));
        }
    }
    
    /**
     * AJAX: Klasördeki resimleri WebP'ye dönüştür
     */
    public function ajax_convert_images_to_webp_in_folder() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_convert_images_to_webp_in_folder', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Parametreleri al
        $folder = isset($_POST['folder']) ? sanitize_text_field($_POST['folder']) : '';
        $quality = isset($_POST['quality']) ? intval($_POST['quality']) : 80;
        $width = isset($_POST['width']) ? intval($_POST['width']) : 0;
        $height = isset($_POST['height']) ? intval($_POST['height']) : 0;
        $formats = isset($_POST['formats']) ? $_POST['formats'] : array('jpg', 'jpeg', 'png');
        
        // Parametreleri kontrol et
        if (empty($folder)) {
            wp_send_json_error(array('message' => __('Geçersiz klasör!', 'advanced-image-management')));
        }
        
        // Kalite değerini sınırla
        $quality = max(1, min(100, $quality));
        
        try {
            // Upload dizinini al
            $upload_dir = wp_upload_dir();
            $base_dir = $upload_dir['basedir'];
            $full_dir = $base_dir . $folder;
            
            // Dizin var mı kontrol et
            if (!is_dir($full_dir)) {
                wp_send_json_error(array('message' => __('Dizin bulunamadı!', 'advanced-image-management')));
            }
            
            // WebP dönüştürme için GD kütüphanesi kontrolü
            if (!function_exists('imagewebp')) {
                wp_send_json_error(array('message' => __('Sunucunuz WebP dönüştürme için uyumlu değil!', 'advanced-image-management')));
            }
            
            // İşlem sonuçları
            $processed = 0;
            $success = 0;
            $error = 0;
            $saved_size = 0;
            
            // Dizindeki dosyaları tara
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($full_dir, RecursiveDirectoryIterator::SKIP_DOTS),
                RecursiveIteratorIterator::SELF_FIRST,
                RecursiveIteratorIterator::CATCH_GET_CHILD
            );
            
            foreach ($files as $file) {
                if ($file->isFile()) {
                    $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                    
                    if (in_array($extension, $formats)) {
                        $processed++;
                        
                        // WebP dosya yolu
                        $webp_file = pathinfo($file->getPathname(), PATHINFO_DIRNAME) . '/' . pathinfo($file->getPathname(), PATHINFO_FILENAME) . '.webp';
                        
                        // Orijinal dosya boyutu
                        $original_size = $file->getSize();
                        
                        // GD kütüphanesi ile WebP dönüştürme
                        // Kaynak resmi yükle
                        $image = null;
                        
                        switch ($extension) {
                            case 'jpg':
                            case 'jpeg':
                                $image = @imagecreatefromjpeg($file->getPathname());
                                break;
                            case 'png':
                                $image = @imagecreatefrompng($file->getPathname());
                                // PNG şeffaflığını koru
                                if ($image) {
                                    imagepalettetotruecolor($image);
                                    imagealphablending($image, true);
                                    imagesavealpha($image, true);
                                }
                                break;
                            case 'gif':
                                $image = @imagecreatefromgif($file->getPathname());
                                break;
                        }
                        
                        // Resim yüklenemediyse devam et
                        if (!$image) {
                            $error++;
                            continue;
                        }
                        
                        // Yeniden boyutlandırma gerekli mi kontrol et
                        if ($width > 0 || $height > 0) {
                            $orig_width = imagesx($image);
                            $orig_height = imagesy($image);
                            
                            // Yeni boyutları hesapla
                            $new_width = $width > 0 ? $width : $orig_width;
                            $new_height = $height > 0 ? $height : $orig_height;
                            
                            // Oranları koru
                            if ($width > 0 && $height <= 0) {
                                $new_height = round(($new_width / $orig_width) * $orig_height);
                            } elseif ($width <= 0 && $height > 0) {
                                $new_width = round(($new_height / $orig_height) * $orig_width);
                            }
                            
                            // Yeni resim oluştur
                            $new_image = imagecreatetruecolor($new_width, $new_height);
                            
                            // PNG şeffaflığını koru
                            if ($extension == 'png') {
                                imagealphablending($new_image, false);
                                imagesavealpha($new_image, true);
                                $transparent = imagecolorallocatealpha($new_image, 255, 255, 255, 127);
                                imagefilledrectangle($new_image, 0, 0, $new_width, $new_height, $transparent);
                            }
                            
                            // Yeniden boyutlandır
                            imagecopyresampled($new_image, $image, 0, 0, 0, 0, $new_width, $new_height, $orig_width, $orig_height);
                            
                            // Eski resmi serbest bırak
                            imagedestroy($image);
                            $image = $new_image;
                        }
                        
                        // WebP olarak kaydet
                        $save_result = imagewebp($image, $webp_file, $quality);
                        
                        // Belleği temizle
                        imagedestroy($image);
                        
                        if ($save_result) {
                            $success++;
                            
                            // Kazanılan alanı hesapla
                            $webp_size = filesize($webp_file);
                            $saved_size += ($original_size - $webp_size);
                        } else {
                            $error++;
                        }
                    }
                }
            }
            
            // İstatistikleri güncelle
            $settings = get_option('awc_settings', array());
            $statistics = isset($settings['statistics']) ? $settings['statistics'] : array(
                'original_size' => 0,
                'converted_size' => 0,
                'saved_size' => 0,
                'converted_count' => 0,
                'deleted_count' => 0,
                'last_update' => 0
            );
            
            $statistics['converted_count'] += $success;
            $statistics['saved_size'] += $saved_size;
            $statistics['last_update'] = time();
            
            $settings['statistics'] = $statistics;
            update_option('awc_settings', $settings);
            
            wp_send_json_success(array(
                'processed' => $processed,
                'success' => $success,
                'error' => $error,
                'saved_size' => $saved_size
            ));
        } catch (Exception $e) {
            wp_send_json_error(array(
                'message' => __('Resimler WebP formatına dönüştürülürken bir hata oluştu!', 'advanced-image-management'),
                'error' => $e->getMessage()
            ));
        }
    }
    
    /**
     * AJAX: Yeniden boyutlandırma için klasörü analiz et
     */
    public function ajax_analyze_folder_for_resize() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_analyze_folder_for_resize', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Parametreleri al
        $folder = isset($_POST['folder']) ? sanitize_text_field($_POST['folder']) : '';
        
        // Parametreleri kontrol et
        if (empty($folder)) {
            wp_send_json_error(array('message' => __('Geçersiz klasör!', 'advanced-image-management')));
        }
        
        try {
            // Upload dizinini al
            $upload_dir = wp_upload_dir();
            $base_dir = $upload_dir['basedir'];
            $full_dir = $base_dir . $folder;
            
            // Dizin var mı kontrol et
            if (!is_dir($full_dir)) {
                wp_send_json_error(array('message' => __('Dizin bulunamadı!', 'advanced-image-management')));
            }
            
            // İşlem sonuçları
            $total_images = 0;
            $total_size_bytes = 0;
            $format_counts = array();
            
            // Resim formatları
            $image_formats = array('jpg', 'jpeg', 'png', 'gif', 'webp');
            
            // Dizindeki dosyaları tara
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($full_dir, RecursiveDirectoryIterator::SKIP_DOTS),
                RecursiveIteratorIterator::SELF_FIRST,
                RecursiveIteratorIterator::CATCH_GET_CHILD
            );
            
            foreach ($files as $file) {
                if ($file->isFile()) {
                    $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                    
                    if (in_array($extension, $image_formats)) {
                        $total_images++;
                        $total_size_bytes += $file->getSize();
                        
                        // Format sayılarını güncelle
                        if (isset($format_counts[$extension])) {
                            $format_counts[$extension]++;
                        } else {
                            $format_counts[$extension] = 1;
                        }
                    }
                }
            }
            
            wp_send_json_success(array(
                'total_images' => $total_images,
                'total_size_bytes' => $total_size_bytes,
                'format_counts' => $format_counts
            ));
        } catch (Exception $e) {
            wp_send_json_error(array(
                'message' => __('Klasör analizi sırasında bir hata oluştu!', 'advanced-image-management'),
                'error' => $e->getMessage()
            ));
        }
    }
    
    /**
     * AJAX: WebP dönüştürme için klasörü analiz et
     */
    public function ajax_analyze_folder_for_webp() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_analyze_folder_for_webp', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        // Parametreleri al
        $folder = isset($_POST['folder']) ? sanitize_text_field($_POST['folder']) : '';
        
        // Parametreleri kontrol et
        if (empty($folder)) {
            wp_send_json_error(array('message' => __('Geçersiz klasör!', 'advanced-image-management')));
        }
        
        try {
            // Upload dizinini al
            $upload_dir = wp_upload_dir();
            $base_dir = $upload_dir['basedir'];
            $full_dir = $base_dir . $folder;
            
            // Dizin var mı kontrol et
            if (!is_dir($full_dir)) {
                wp_send_json_error(array('message' => __('Dizin bulunamadı!', 'advanced-image-management')));
            }
            
            // İşlem sonuçları
            $total_images = 0;
            $total_size_bytes = 0;
            $format_counts = array();
            $webp_count = 0;
            $webp_size_bytes = 0;
            
            // Resim formatları
            $image_formats = array('jpg', 'jpeg', 'png', 'gif', 'webp');
            
            // Dizindeki dosyaları tara
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($full_dir, RecursiveDirectoryIterator::SKIP_DOTS),
                RecursiveIteratorIterator::SELF_FIRST,
                RecursiveIteratorIterator::CATCH_GET_CHILD
            );
            
            foreach ($files as $file) {
                if ($file->isFile()) {
                    $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                    
                    if (in_array($extension, $image_formats)) {
                        if ($extension === 'webp') {
                            $webp_count++;
                            $webp_size_bytes += $file->getSize();
                        } else {
                            $total_images++;
                            $total_size_bytes += $file->getSize();
                            
                            // Format sayılarını güncelle
                            if (isset($format_counts[$extension])) {
                                $format_counts[$extension]++;
                            } else {
                                $format_counts[$extension] = 1;
                            }
                            
                            // WebP versiyonu var mı kontrol et
                            $webp_file = pathinfo($file->getPathname(), PATHINFO_DIRNAME) . '/' . pathinfo($file->getPathname(), PATHINFO_FILENAME) . '.webp';
                            
                            if (file_exists($webp_file)) {
                                if (isset($format_counts['webp_converted'])) {
                                    $format_counts['webp_converted']++;
                                } else {
                                    $format_counts['webp_converted'] = 1;
                                }
                            }
                        }
                    }
                }
            }
            
            wp_send_json_success(array(
                'total_images' => $total_images,
                'total_size_bytes' => $total_size_bytes,
                'format_counts' => $format_counts,
                'webp_count' => $webp_count,
                'webp_size_bytes' => $webp_size_bytes
            ));
        } catch (Exception $e) {
            wp_send_json_error(array(
                'message' => __('Klasör analizi sırasında bir hata oluştu!', 'advanced-image-management'),
                'error' => $e->getMessage()
            ));
        }
    }
    
    /**
     * AJAX: Genel istatistikleri al
     */
    public function ajax_get_overall_statistics() {
        // Güvenlik kontrolü
        check_ajax_referer('awc_get_overall_statistics', 'nonce');
        
        // Yetki kontrolü
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => __('Yetkiniz yok!', 'advanced-image-management')));
        }
        
        try {
            // Upload dizinini al
            $upload_dir = wp_upload_dir();
            $base_dir = $upload_dir['basedir'];
            
            // İşlem sonuçları
            $total_images = 0;
            $total_size_bytes = 0;
            $format_counts = array();
            $webp_count = 0;
            $webp_size_bytes = 0;
            
            // Resim formatları
            $image_formats = array('jpg', 'jpeg', 'png', 'gif', 'webp');
            
            // Dizindeki dosyaları tara
            $files = new RecursiveIteratorIterator(
                new RecursiveDirectoryIterator($base_dir, RecursiveDirectoryIterator::SKIP_DOTS),
                RecursiveIteratorIterator::SELF_FIRST,
                RecursiveIteratorIterator::CATCH_GET_CHILD
            );
            
            foreach ($files as $file) {
                if ($file->isFile()) {
                    $extension = strtolower(pathinfo($file->getPathname(), PATHINFO_EXTENSION));
                    
                    if (in_array($extension, $image_formats)) {
                        if ($extension === 'webp') {
                            $webp_count++;
                            $webp_size_bytes += $file->getSize();
                        } else {
                            $total_images++;
                            $total_size_bytes += $file->getSize();
                            
                            // Format sayılarını güncelle
                            if (isset($format_counts[$extension])) {
                                $format_counts[$extension]++;
                            } else {
                                $format_counts[$extension] = 1;
                            }
                            
                            // WebP versiyonu var mı kontrol et
                            $webp_file = pathinfo($file->getPathname(), PATHINFO_DIRNAME) . '/' . pathinfo($file->getPathname(), PATHINFO_FILENAME) . '.webp';
                            
                            if (file_exists($webp_file)) {
                                if (isset($format_counts['webp_converted'])) {
                                    $format_counts['webp_converted']++;
                                } else {
                                    $format_counts['webp_converted'] = 1;
                                }
                            }
                        }
                    }
                }
            }
            
            // Tasarruf hesapla
            $saved_size = $total_size_bytes - $webp_size_bytes;
            $saved_percentage = $total_size_bytes > 0 ? round(($saved_size / $total_size_bytes) * 100, 2) : 0;
            
            wp_send_json_success(array(
                'total_images' => $total_images,
                'total_size_bytes' => $total_size_bytes,
                'total_size_formatted' => size_format($total_size_bytes),
                'format_counts' => $format_counts,
                'webp_count' => $webp_count,
                'webp_size_bytes' => $webp_size_bytes,
                'webp_size_formatted' => size_format($webp_size_bytes),
                'saved_size_bytes' => $saved_size,
                'saved_size_formatted' => size_format($saved_size),
                'saved_percentage' => $saved_percentage
            ));
        } catch (Exception $e) {
            wp_send_json_error(array(
                'message' => __('İstatistikler alınırken bir hata oluştu!', 'advanced-image-management'),
                'error' => $e->getMessage()
            ));
        }
    }
    
    /**
     * Resim varyasyonlarını al (dahili kullanım için)
     */
    private function get_image_variations_data() {
        // Upload dizinini al
        $upload_dir = wp_upload_dir();
        $base_dir = $upload_dir['basedir'];
        
        // Resim varyasyonları
        $variations = array();
        
        // Resim formatları
        $settings = get_option('awc_settings', array());
        $image_formats = isset($settings['image_formats']) ? $settings['image_formats'] : array('jpg', 'jpeg', 'png', 'gif');
        
        // WordPress'in oluşturduğu boyutları al
        $image_sizes = get_intermediate_image_sizes();
        
        // Varyasyon kategorilerini oluştur
        $variations['original'] = array(
		/* translators: %s: İşlem sonucunu gösterir */
            'name' => __('Orijinal Resimler', 'advanced-image-management'),
            'count' => 0,
            'size' => 0,
            'files' => array()
        );
        
        $variations['webp'] = array(
		/* translators: %s: İşlem sonucunu gösterir */
            'name' => __('WebP Dönüşümleri', 'advanced-image-management'),
            'count' => 0,
            'size' => 0,
            'files' => array()
        );
        
        foreach ($image_sizes as $size) {
            $variations[$size] = array(
			/* translators: %s: İşlem sonucunu gösterir */
                'name' => sprintf(__('%s Boyutu', 'advanced-image-management'), ucfirst($size)),
                'count' => 0,
                'size' => 0,
                'files' => array()
            );
            
            $variations[$size . '_webp'] = array(
			/* translators: %s: İşlem sonucunu gösterir */
                'name' => sprintf(__('%s Boyutu WebP', 'advanced-image-management'), ucfirst($size)),
                'count' => 0,
                'size' => 0,
                'files' => array()
            );
        }
        
        // Medya kütüphanesindeki resimleri al
        $args = array(
            'post_type' => 'attachment',
            'post_mime_type' => 'image',
            'post_status' => 'inherit',
            'posts_per_page' => -1,
        );
        
        $query = new WP_Query($args);
        
        if ($query->have_posts()) {
            while ($query->have_posts()) {
                $query->the_post();
                $attachment_id = get_the_ID();
                
                // Resim meta verilerini al
                $metadata = wp_get_attachment_metadata($attachment_id);
                
                if (isset($metadata['file'])) {
                    $file_path = $base_dir . '/' . $metadata['file'];
                    
                    // Dosya gerçekten var mı kontrol et
                    if (file_exists($file_path)) {
                        $dir_path = dirname($file_path);
                        $file_name = basename($file_path);
                        $extension = strtolower(pathinfo($file_path, PATHINFO_EXTENSION));
                        
                        // Orijinal resim
                        if (in_array($extension, $image_formats)) {
                            $original_size = filesize($file_path);
                            $variations['original']['count']++;
                            $variations['original']['size'] += $original_size;
                            $variations['original']['files'][] = $file_path;
                            
                            // WebP versiyonu
                            $webp_file = pathinfo($file_path, PATHINFO_DIRNAME) . '/' . pathinfo($file_path, PATHINFO_FILENAME) . '.webp';
                            
                            if (file_exists($webp_file)) {
                                $webp_size = filesize($webp_file);
                                $variations['webp']['count']++;
                                $variations['webp']['size'] += $webp_size;
                                $variations['webp']['files'][] = $webp_file;
                            }
                            
                            // Resim boyutları
                            if (isset($metadata['sizes'])) {
                                foreach ($metadata['sizes'] as $size => $size_info) {
                                    if (isset($size_info['file'])) {
                                        $size_file = $dir_path . '/' . $size_info['file'];
                                        
                                        if (file_exists($size_file)) {
                                            $size_file_size = filesize($size_file);
                                            
                                            if (isset($variations[$size])) {
                                                $variations[$size]['count']++;
                                                $variations[$size]['size'] += $size_file_size;
                                                $variations[$size]['files'][] = $size_file;
                                            }
                                            
                                            // WebP versiyonu
                                            $size_webp_file = $dir_path . '/' . pathinfo($size_info['file'], PATHINFO_FILENAME) . '.webp';
                                            
                                            if (file_exists($size_webp_file)) {
                                                $size_webp_size = filesize($size_webp_file);
                                                $size_webp_key = $size . '_webp';
                                                
                                                if (isset($variations[$size_webp_key])) {
                                                    $variations[$size_webp_key]['count']++;
                                                    $variations[$size_webp_key]['size'] += $size_webp_size;
                                                    $variations[$size_webp_key]['files'][] = $size_webp_file;
                                                }
                                            }
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
            
            wp_reset_postdata();
        }
        
        // Boş varyasyonları kaldır
        foreach ($variations as $key => $variation) {
            if ($variation['count'] == 0) {
                unset($variations[$key]);
            }
        }
        
        return $variations;
    }
}

// Eklentiyi başlat
function auto_webp_converter() {
    return Auto_WebP_Converter::get_instance();
}

// Eklentiyi çalıştır
auto_webp_converter();
